Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(925)

Unified Diff: media/base/audio_renderer.h

Issue 1423163004: media: Replace DecryptorReadyCB with CdmReadyCB. (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: comments addressed Created 5 years, 1 month ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « content/renderer/media/android/webmediaplayer_android.cc ('k') | media/base/cdm_context.h » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: media/base/audio_renderer.h
diff --git a/media/base/audio_renderer.h b/media/base/audio_renderer.h
index 586936a1e81bc4e5f94da23ffc12bd2f6904e514..aa59bf30ffd2f563b83801e70de08d9c6f8c07f3 100644
--- a/media/base/audio_renderer.h
+++ b/media/base/audio_renderer.h
@@ -8,7 +8,7 @@
#include "base/callback.h"
#include "base/time/time.h"
#include "media/base/buffering_state.h"
-#include "media/base/decryptor.h"
+#include "media/base/cdm_context.h"
#include "media/base/media_export.h"
#include "media/base/pipeline_status.h"
@@ -28,8 +28,8 @@ class MEDIA_EXPORT AudioRenderer {
// completion. If initialization fails, only |init_cb| (not |error_cb|) will
// be called.
//
// |set_decryptor_ready_cb| is fired when a Decryptor is needed, i.e. when the
// |stream| is encrypted.
//
// |statistics_cb| is executed periodically with audio rendering stats.
//
@@ -45,7 +45,7 @@ class MEDIA_EXPORT AudioRenderer {
virtual void Initialize(
DemuxerStream* stream,
const PipelineStatusCB& init_cb,
- const SetDecryptorReadyCB& set_decryptor_ready_cb,
+ const SetCdmReadyCB& set_cdm_ready_cb,
const StatisticsCB& statistics_cb,
const BufferingStateCB& buffering_state_cb,
const base::Closure& ended_cb,
@@ -28,8 +28,8 @@ class MEDIA_EXPORT AudioRenderer {
// be called.
//
- // |set_decryptor_ready_cb| is fired when a Decryptor is needed, i.e. when the
- // |stream| is encrypted.
+ // |set_cdm_ready_cb| is fired when a CDM is needed, i.e. when the |stream| is
+ // encrypted.
//
// |statistics_cb| is executed periodically with audio rendering stats.
« no previous file with comments | « content/renderer/media/android/webmediaplayer_android.cc ('k') | media/base/cdm_context.h » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698